searchData={"items":[{"type":"module","title":"Heyya","doc":"Heyya is here to help with you testing. It provides a\nset of ExUnit CaseTemplate's that make it easier to test Phoenix\nComponents, LiveViews, and LiveComponent's.","ref":"Heyya.html"},{"type":"module","title":"Heyya.LiveCase","doc":"`Heyya.LiveCase` module provides helper methods that make it easier to write a\nmore linear live view test. It takes care of the fact that there's\nconnection state, view state, and last html state.\n\n\nIt does this by creating a `LiveTestSession` struct via `start/2` that\nholds the connection, view, and html in a single struct. This is\nwrapped in an CaseTemplate so that you can use it in your tests.\n\nThese ideas origionally came from: https://www.reddit.com/r/elixir/comments/ydyt2m/better_liveview_tests/\n\nThis implementation doesn't hide follow (in large part because\nof the ergonomics of follow_redirect being a macro)","ref":"Heyya.LiveCase.html"},{"type":"module","title":"Example - Heyya.LiveCase","doc":"```\ndefmodule MyPhoenixWeb.ListLiveTest do\n  use Heyya.LiveCase\n  use MyPhoenixWeb.ConnCase\n\n  test \"widget list with new button\", %{conn: conn} do\n    start(conn, ~p|/widgets|)\n    |> assert_html(\"Widgets List\")\n    |> click(\"a\", \"New Widgets\")\n    |> follow(~p|/widgets/new|)\n  end\nend\n```","ref":"Heyya.LiveCase.html#module-example"},{"type":"function","title":"Heyya.LiveCase.assert_element/3","doc":"","ref":"Heyya.LiveCase.html#assert_element/3"},{"type":"function","title":"Heyya.LiveCase.assert_html/2","doc":"Asserts that the html in the LiveTestSession matches the\nprovided expected html.\n\nReturns the LiveTestSession.","ref":"Heyya.LiveCase.html#assert_html/2"},{"type":"function","title":"Heyya.LiveCase.assert_page_title/2","doc":"","ref":"Heyya.LiveCase.html#assert_page_title/2"},{"type":"function","title":"Heyya.LiveCase.await_async/2","doc":"This method will use LiveViewTest.render_async to ensure that all\noutstanding async operations are completed.  By default this\nwill wait the ExUnit default timeout.","ref":"Heyya.LiveCase.html#await_async/2"},{"type":"function","title":"Heyya.LiveCase.click/3","doc":"This method clicks on an element that's selected via selector then renders\nthe result. Finally returning a new LiveTestSession with updated rendered html\n\nThis will also assert that there is an element that's specified by the selector\n\nThis doesn't follow navigations or redirect.\n\nreturns: `%Heyya.LiveTestSession{}`","ref":"Heyya.LiveCase.html#click/3"},{"type":"function","title":"Heyya.LiveCase.focus/2","doc":"","ref":"Heyya.LiveCase.html#focus/2"},{"type":"macro","title":"Heyya.LiveCase.follow/2","doc":"Macro that creates code to follow a redirect. This takes\nin a LiveTestSession and will assert that a redirect exists.","ref":"Heyya.LiveCase.html#follow/2"},{"type":"function","title":"Heyya.LiveCase.form/3","doc":"Sets the form specified by the selector to a new value.\n\nThis doesn't submit the form\n\nreturns: `%Heyya.LiveTestSession{}`","ref":"Heyya.LiveCase.html#form/3"},{"type":"function","title":"Heyya.LiveCase.refute_element/3","doc":"","ref":"Heyya.LiveCase.html#refute_element/3"},{"type":"function","title":"Heyya.LiveCase.refute_html/2","doc":"Refute that the html in the LiveTestSession matches the provided html string.\n\nReturns the LiveTestSession.","ref":"Heyya.LiveCase.html#refute_html/2"},{"type":"function","title":"Heyya.LiveCase.refute_page_title/2","doc":"","ref":"Heyya.LiveCase.html#refute_page_title/2"},{"type":"macro","title":"Heyya.LiveCase.start/2","doc":"Macro that creates code to start a new LiveTestSession. This takes in a plug\nconnection (Usually from your ConnTest)","ref":"Heyya.LiveCase.html#start/2"},{"type":"function","title":"Heyya.LiveCase.submit_form/3","doc":"Submits the form and renders the result of submitting.\n\nThis doesn't follow any redirects.\n\nreturns: `%Heyya.LiveTestSession{}`","ref":"Heyya.LiveCase.html#submit_form/3"},{"type":"module","title":"Heyya.LiveComponentCase","doc":"A test case template that provides helpers\n  for testing live components. It relies on LiveComponentHost\n  being mounted.\n\n  It allows for testing dyanmic content such as\n  live components with a simplified stack.","ref":"Heyya.LiveComponentCase.html"},{"type":"module","title":"Usage - Heyya.LiveComponentCase","doc":"```elixir\n  # component_test.exs\n  use Heyya.LiveComponentCase\n  use ExampleWeb.ConnCase\n\n  # By default LiveComponentCase will look for a render function in the module\n  def render(assigns) do\n    ~H|<.live_component module={ExampleWeb.LiveCounterComponent} id=\"example\" />|\n  end\n\n  test \"Test Counter\", %{conn: conn} do\n    conn\n    |> start()\n    |> click(\"button.increment\")\n    |> assert_html(\"Counter: 1\")\n  end\n  ```","ref":"Heyya.LiveComponentCase.html#module-usage"},{"type":"module","title":"Options - Heyya.LiveComponentCase","doc":"- `:view_module` - The module that will render the live component\n  - `:view_method` - The method that will render the live component\n  - `:base_path` - The path to the live component host. Defaults to \"/dev/heyya/host\"\n\n  ## `Heyya.LiveComponentHost`\n\n  The `Heyya.LiveComponentHost` is a live view that renders only a single live\n  component with no other layout or content. It is used to test live components in\n  isolation of so don't mount it in scope with complex Plugs.\n\n  ```elixir\n  if Enum.member?([:dev, :test], Mix.env()) do\n    scope \"/dev\" do\n      pipe_through :browser\n      live \"/heyya/host\", Heyya.LiveComponentHost\n    end\n  end\n  ```","ref":"Heyya.LiveComponentCase.html#module-options"},{"type":"macro","title":"Heyya.LiveComponentCase.start/1","doc":"","ref":"Heyya.LiveComponentCase.html#start/1"},{"type":"module","title":"Heyya.LiveComponentHost","doc":"This live view takes in a Module name and a\nmethod name then dynamically renders it. Params\n(other than module anme and method name) are\npassed along to the function as assigns.\n\nContent is wrapped in a div with\nid \"heyya-inner-content\" so that we know what\noutter chrome can be ignored.","ref":"Heyya.LiveComponentHost.html"},{"type":"function","title":"Heyya.LiveComponentHost.empty_layout/1","doc":"","ref":"Heyya.LiveComponentHost.html#empty_layout/1"},{"type":"module","title":"Heyya.LiveTestSession","doc":"This module is a struct to hold the state of a session of live view testing.\n\nIt wraps up Plug connection, the current view, and the latest rendered html","ref":"Heyya.LiveTestSession.html"},{"type":"type","title":"Heyya.LiveTestSession.t/0","doc":"","ref":"Heyya.LiveTestSession.html#t:t/0"},{"type":"module","title":"Heyya.SnapshotCase","doc":"`Heyya.SnapshotCase` allows for fast snapshot\ntesting of Phoenix components. Snapshot testing\ncomponents is a fast and easy way to ensure that\nthey work and produce what they expected to\nproduce without having to hand write\nassertions.","ref":"Heyya.SnapshotCase.html"},{"type":"module","title":"Complex Tests Made Easy - Heyya.SnapshotCase","doc":"Suppose you have a component button with a color\nand and icon. You want to test that the correct\ncss class is applied to the whole dom tree. Instead\nassert that the dom tree is functionally equivalent\nto the expected output.\n\n```elixir\ncomponent_snapshot_test \"Eiffel 65\" do\n  assigns = %{}\n\n  ~H|<.button phx-click=\"click\" class=\"bg-blue-500\">Click me</.button>|\nend\n```","ref":"Heyya.SnapshotCase.html#module-complex-tests-made-easy"},{"type":"module","title":"Change Tests Faster - Heyya.SnapshotCase","doc":"Any changes to that would require changes to the\ntest are easily updated by running the tests and\nupdating the snapshots. This happens by setting the\nenvironment variable `HEYYA_OVERRIDE` to `true` or `1`.\n\n```\nHEYYA_OVERRIDE=true mix test\n```","ref":"Heyya.SnapshotCase.html#module-change-tests-faster"},{"type":"macro","title":"Heyya.SnapshotCase.__using__/1","doc":"Wire up the module to prepare for snapshot testing.","ref":"Heyya.SnapshotCase.html#__using__/1"},{"type":"function","title":"Heyya.SnapshotCase.compare_html/2","doc":"","ref":"Heyya.SnapshotCase.html#compare_html/2"},{"type":"macro","title":"Heyya.SnapshotCase.component_snapshot_test/2","doc":"A named component snapshot test","ref":"Heyya.SnapshotCase.html#component_snapshot_test/2"},{"type":"macro","title":"Heyya.SnapshotCase.component_snapshot_test/3","doc":"A named component snapshot test, where context is passed through.","ref":"Heyya.SnapshotCase.html#component_snapshot_test/3"},{"type":"function","title":"Heyya.SnapshotCase.directory/1","doc":"Gets the directory to store snapshot files for the test.","ref":"Heyya.SnapshotCase.html#directory/1"},{"type":"function","title":"Parameters - Heyya.SnapshotCase.directory/1","doc":"- env: The macro environment which contains metadata about the test file.","ref":"Heyya.SnapshotCase.html#directory/1-parameters"},{"type":"function","title":"Returns - Heyya.SnapshotCase.directory/1","doc":"The directory path as a binary where snapshots should be stored.","ref":"Heyya.SnapshotCase.html#directory/1-returns"},{"type":"function","title":"Heyya.SnapshotCase.filename/1","doc":"","ref":"Heyya.SnapshotCase.html#filename/1"},{"type":"function","title":"Heyya.SnapshotCase.get_snapshot/1","doc":"Gets the stored snapshot for the given macro environment.\n\nThis looks up the snapshot file path and name based on the environment,\nreads the file contents, and returns the snapshot.\n\nIf there is no snapshot file yet, returns an empty binary.","ref":"Heyya.SnapshotCase.html#get_snapshot/1"},{"type":"function","title":"Parameters - Heyya.SnapshotCase.get_snapshot/1","doc":"- env: The macro environment which contains metadata about the test module and function.","ref":"Heyya.SnapshotCase.html#get_snapshot/1-parameters"},{"type":"function","title":"Returns - Heyya.SnapshotCase.get_snapshot/1","doc":"The stored snapshot as a binary, or empty binary if no snapshot exists.","ref":"Heyya.SnapshotCase.html#get_snapshot/1-returns"},{"type":"macro","title":"Heyya.SnapshotCase.inner_test/1","doc":"","ref":"Heyya.SnapshotCase.html#inner_test/1"},{"type":"function","title":"Heyya.SnapshotCase.override!/2","doc":"","ref":"Heyya.SnapshotCase.html#override!/2"},{"type":"function","title":"Heyya.SnapshotCase.override?/0","doc":"","ref":"Heyya.SnapshotCase.html#override?/0"},{"type":"extras","title":"Heyya","doc":"# Heyya\n\n`Heyya` is a utility to help with testing your [Phoenix](https://www.phoenixframework.org/) components and live view.","ref":"readme.html"},{"type":"extras","title":"Getting Started - Heyya","doc":"Getting Started\n\nTo use Heyya in your Phoenix project, add it to your list of dependencies in mix.exs:\n\n```elixir\ndef deps do\n  [\n    {:heyya, \"~> 0.8.0\"}\n  ]\nend\n```\n\nThen, run `mix deps.get` to install Heyya and its dependencies. Use some case templates provided that make testing easier and more automated.","ref":"readme.html#getting-started"},{"type":"extras","title":"Examples - Heyya","doc":"In order to show how the different tests can be\nimplemented we have an example Phoenix project in the example\nproject.\n\nChanges of note are:\n\n- Added two example live views that show simple pages.\n- Added the Heyya dependency\n- Added the `/dev/heyya/host` route for dev and test environments\n- Added snapshot component tests that show variants get expected classes and aggregate components combine as expected.\n- Added live view tests that show Heyya's full page live view testing utilities. Open a page and surf around.\n- Added a live_component tests that shows stateful component testing with dynamic content without full page data load.\n\n#","ref":"readme.html#examples"},{"type":"extras","title":"Example Snapshot Usage - Heyya","doc":"```\nuse Heyya.SnapshotCase\n\ncomponent_snapshot_test \"Super Simple H1 Test\" do\n  assigns = %{}\n\n  ~H\"\"\"\n   Testing \n  \"\"\"\nend\n```\n\nTo run the snapshot tests, run `mix test` as usual. This will compare the snapshots to the current rendered output of the components and fail the tests if the snapshots do not match.\n\nIf you need to update the snapshots for any reason, you can run `HEYYA_OVERRIDE=true mix test` to reset the snapshot values to the current rendered output of the components.\n\nCredit:\n\nThe initial snapshot code used [Snapshy](https://hex.pm/packages/snapshy). We have since moved on to inspect the html rather than using snapshy. Thank you to them for the initial implementation.\n\n#","ref":"readme.html#example-snapshot-usage"},{"type":"extras","title":"Example Live View Test - Heyya","doc":"```\nuse Heyya.LiveCase\nuse MyPhoenixWeb.ConnCase\n\ntest \"widget list with new button\", %{conn: conn} do\n  start(conn, ~p|/widgets|)\n  |> assert_html(\"Widgets List\")\n  |> click(\"a\", \"New Widgets\")\n  |> follow(~p|/widgets/new|)\nend\n```\n\n#","ref":"readme.html#example-live-view-test"},{"type":"extras","title":"Example Live Component Test - Heyya","doc":"In order to test a live view component we need a full\nendpoint. Attach the component host into the Router for test\nenvironments (attaching for debug is nice sometimes too).\n\nThat can be done like this:\n```\nif Enum.member?([:dev, :test], Mix.env()) do\n  scope \"/dev\" do\n    pipe_through :browser\n\n    live \"/heyya/host\", Heyya.LiveComponentHost\n  end\nend\n```\n\nFrom then on `/dev/heyya/host` will host dynamic content with no layout other than a single wrapper div.\n\n\n```\n  use Heyya.LiveComponentCase\n  use ExampleWeb.ConnCase\n  use Phoenix.Component\n\n  def render(assigns) do\n    ~H\"\"\"\n    <.live_component module={ExampleWeb.LiveCounterComponent} id=\"example\" />\n    \"\"\"\n  end\n\n  test \"Test Counter\", %{conn: conn} do\n    conn\n    |> start()\n    |> click(\"button.increment\")\n    |> assert_html(\"Counter: 1\")\n  end\n```","ref":"readme.html#example-live-component-test"},{"type":"extras","title":"Contributing - Heyya","doc":"We welcome contributions to Heyya! Please see the CONTRIBUTING.md file for guidelines on how to contribute.","ref":"readme.html#contributing"},{"type":"extras","title":"License - Heyya","doc":"Heyya is released under the MIT License.","ref":"readme.html#license"}],"content_type":"text/markdown"}